@@ -13,6 +13,8 @@ datakind <- cordat$datakind
 
 eigenvalues <- cbind(eigen(cormat) $values)
 
+totvarexplNOROT <- VarianceExplained(eigenvalues)
+
 NfactorsNEVALSGT1 <- 0
 for (nev in 1:nrow(eigenvalues)) {if (eigenvalues[nev,] > 1) NfactorsNEVALSGT1 <- NfactorsNEVALSGT1 + 1}
 
@@ -27,15 +29,13 @@ if (verbose == TRUE) {
 
 	message('\nSpecified kind of correlations for this analysis: ', ctype, '\n')
 	
-	eigenvar <- eigvalmat(eigenvalues)
-	print(round(eigenvar,5))
+	message('\n\nTotal Variance Explained (Initial Eigenvalues):\n')
+	print(round(totvarexplNOROT,2), print.gap=4)
 	
 	message('\nThe number of eigenvalues greater than one = ', NfactorsNEVALSGT1, '\n')
 }
 
-eigenvar <- eigvalmat(eigenvalues)
-
-nevalsgt1Output <- list(NfactorsNEVALSGT1=NfactorsNEVALSGT1, eigenvar=eigenvar)
+nevalsgt1Output <- list(NfactorsNEVALSGT1=NfactorsNEVALSGT1, totvarexplNOROT=totvarexplNOROT)
 
 return(invisible(nevalsgt1Output))
 
